summaryrefslogtreecommitdiffstats
path: root/drivers/net/tap.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/net/tap.c')
-rw-r--r--drivers/net/tap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/net/tap.c b/drivers/net/tap.c
index 7070cc6b41..8673436caf 100644
--- a/drivers/net/tap.c
+++ b/drivers/net/tap.c
@@ -1,5 +1,5 @@
/*
* tap.c - A tap ethernet driver for U-Boot
*
* Copyright (c) 2007 Sascha Hauer <s.hauer@pengutronix.de>, Pengutronix
*
@@ -80,7 +80,7 @@ int tap_probe(struct device_d *dev)
int ret = 0;
priv = malloc(sizeof(struct tap_priv));
- priv->name = "uboot";
+ priv->name = "barebox";
priv->fd = tap_alloc(priv->name);
if (priv->fd < 0) {
@@ -1,5 +1,5 @@
/*
- * tap.c - A tap ethernet driver for U-Boot
+ * tap.c - A tap ethernet driver for barebox
*
* Copyright (c) 2007 Sascha Hauer <s.hauer@pengutronix.de>, Pengutronix